==> 0.0.5.tar.gz: lib/src/field_view.dart <==
library fields.field_view;

import 'dart:async';
import 'dart:html';
import 'package:tags/builder.dart';
import 'package:tags/custom.dart';
import 'package:tags/html.dart';
import 'field.dart';
import 'field_editor.dart';
import 'theme.dart';
import 'field_list_view.dart';

final Tag fieldView = 
    ([Build b, List args]) => 
        build(() => bind(new FieldView(args[0]), args[1]), b);    

class FieldViewResources {
  String get style =>
"""
.expander {
  background-color:transparent;
  border-style:none;
  color:${fieldsTheme.colors.text};
  float:left;   
  width:16px;
  padding:0;
  margin-top:4px;
}
.editorbox {
  display:block; 
  overflow:hidden;  
}
""";
  const FieldViewResources();
}

class FieldView implements HasElement {  
  
  Element _element;
  Element get element => _element;
  
  final FieldListView _list = new FieldListView();  
  ToggleButton _toggle;
  
  final Field _field;
  Field get field => _field;
           
  FieldEditor _editor;  
  bool get _isExpanded => _toggle.isDown;
  
  FieldView(this._field, 
            [FieldViewResources res = const FieldViewResources()]) {    
    _editor = new FieldEditor.forField(_field);
    
    _element =
        span(() {
          shadow(() {
            style()..text = res.style;            
            toggleButton(() {
              span()..innerHtml = '&#9655;'..classes = ['up'];
              span()..innerHtml = '&#9698;'..classes = ['down'];
            }, (ToggleButton toggle) {
              _toggle = toggle;
              _toggle.states.listen((_) => render());
            })..classes.add('expander');
            span(() {
              append(_editor.element);
            })..classes.add('editorbox');
            append(_list.element);
          });
        });
        
    field.values.listen((_) => _render());
    _render();
  }
  
  void render() {
    if (_isExpanded) _list.render(_field.children);
    else _list.render([]);
    _render();
  }
  
  void _render() {
    _toggle.element.hidden = _field.children.isEmpty;
    _list.element.hidden = !_isExpanded;    
  }  
}

==> 0.0.8.tar.gz: lib/src/field_view.dart <==
library fields.field_view;

import 'dart:async';
import 'dart:html';
import 'package:tags/tags.dart';
import 'field.dart';
import 'field_editor.dart';
import 'theme.dart';
import 'field_list_view.dart';

final Tag fieldView = 
    ([BuildChildren b, List args]) => 
        buildNode(() => bindModel(new FieldView(args[0]), args[1]), b);    

class FieldViewResources {
  String get style =>
"""
.expander {
  background-color:transparent;
  border-style:none;
  color:${fieldsTheme.colors.text};
  float:left;   
  width:16px;
  padding:0;
  margin-top:4px;
}
.editorbox {
  display:block; 
  overflow:hidden;  
}
""";
  const FieldViewResources();
}

class FieldView implements HasElement {  
  
  Element _element;
  Element get element => _element;
  
  final FieldListView _list = new FieldListView();  
  ToggleButton _toggle;
  
  final Field _field;
  Field get field => _field;
           
  FieldEditor _editor;  
  bool get _isExpanded => _toggle.isDown;
  
  FieldView(this._field, 
            [FieldViewResources res = const FieldViewResources()]) {    
    _editor = new FieldEditor.forField(_field);
    
    _element =
        span(() {
          shadow(() {
            style()..text = res.style;            
            toggleButton(() {
              span()..innerHtml = '&#9655;'..classes = ['up'];
              span()..innerHtml = '&#9698;'..classes = ['down'];
            }, (ToggleButton toggle) {
              _toggle = toggle;
              _toggle.states.listen((_) => render());
            })..classes.add('expander');
            span(() {
              append(_editor.element);
            })..classes.add('editorbox');
            append(_list.element);
          });
        });
        
    field.values.listen((_) => _render());
    _render();
  }
  
  void render() {
    if (_isExpanded) _list.render(_field.children);
    else _list.render([]);
    _render();
  }
  
  void _render() {
    _toggle.element.hidden = _field.children.isEmpty;
    _list.element.hidden = !_isExpanded;    
  }  
}
